diff --git a/core/src/processing/core/PGraphics.java b/core/src/processing/core/PGraphics.java
index bdc044f16..fe59d2c9b 100644
--- a/core/src/processing/core/PGraphics.java
+++ b/core/src/processing/core/PGraphics.java
@@ -1211,7 +1211,7 @@ public class PGraphics extends PImage implements PConstants {
* Description to come...
*
* ( end auto-generated from textureWrap.xml )
- *
+ *
* @webref image:textures
* @param wrap Either CLAMP (default) or REPEAT
*/
@@ -1607,7 +1607,7 @@ public class PGraphics extends PImage implements PConstants {
* This is a new reference entry for Processing 2.0. It will be updated shortly.
*
* ( end auto-generated )
- *
+ *
* @webref Rendering
* @param mode the blending mode to use
*/
@@ -1668,7 +1668,7 @@ public class PGraphics extends PImage implements PConstants {
* This is a new reference entry for Processing 2.0. It will be updated shortly.
*
* ( end auto-generated )
- *
+ *
* @webref rendering:shaders
* @param fragFilename name of fragment shader file
*/
@@ -1691,7 +1691,7 @@ public class PGraphics extends PImage implements PConstants {
* This is a new reference entry for Processing 2.0. It will be updated shortly.
*
* ( end auto-generated )
- *
+ *
* @webref rendering:shaders
* @param shader name of shader file
*/
@@ -1712,7 +1712,7 @@ public class PGraphics extends PImage implements PConstants {
* This is a new reference entry for Processing 2.0. It will be updated shortly.
*
* ( end auto-generated )
- *
+ *
* @webref rendering:shaders
*/
public void resetShader() {
@@ -3332,11 +3332,11 @@ public class PGraphics extends PImage implements PConstants {
public void smooth() {
smooth = true;
}
-
+
/**
- *
+ *
* @param level either 2, 4, or 8
- */
+ */
public void smooth(int level) {
smooth = true;
}
@@ -4736,8 +4736,8 @@ public class PGraphics extends PImage implements PConstants {
* ( end auto-generated )
*
* @webref transform
- * @param tx left/right translation
- * @param ty up/down translation
+ * @param x left/right translation
+ * @param y up/down translation
* @see PGraphics#popMatrix()
* @see PGraphics#pushMatrix()
* @see PGraphics#rotate(float)
@@ -4746,15 +4746,15 @@ public class PGraphics extends PImage implements PConstants {
* @see PGraphics#rotateZ(float)
* @see PGraphics#scale(float, float, float)
*/
- public void translate(float tx, float ty) {
+ public void translate(float x, float y) {
showMissingWarning("translate");
}
/**
- * @param tz forward/backward translation
+ * @param z forward/backward translation
*/
- public void translate(float tx, float ty, float tz) {
+ public void translate(float x, float y, float z) {
showMissingWarning("translate");
}
@@ -4897,11 +4897,11 @@ public class PGraphics extends PImage implements PConstants {
/**
* Advanced
* Rotate about a vector in space. Same as the glRotatef() function.
- * @param vx
- * @param vy
- * @param vz
+ * @param x
+ * @param y
+ * @param z
*/
- public void rotate(float angle, float vx, float vy, float vz) {
+ public void rotate(float angle, float x, float y, float z) {
showMissingWarning("rotate");
}
diff --git a/core/todo.txt b/core/todo.txt
index b901a8d67..d3e1351ce 100644
--- a/core/todo.txt
+++ b/core/todo.txt
@@ -2,6 +2,12 @@
X change to getRows() method for iterating through the Table object
X add parseInto() method (provisional)
+cleaning
+o remove screenBlend(), textureBlend() from PGraphics et al
+o have andres take over all current GL issues in the tracker
+
+_ need to make events interleave
+
_ change translate() and rotate() to use x, y, z as param names
_ add "CGAffineTransformInvert: singular matrix" problem to the Wiki
@@ -251,15 +257,26 @@ _ http://www.html5rocks.com/en/mobile/touch.html
_ decision: go with what looks like javascript/ios
_ touchEvent(), gestureEvent()?
+2.0 / blending
+_ remove blend(), add blendMode()
+_ for Java2D: http://code.google.com/p/processing/issues/detail?id=1385
+_ for Android: http://code.google.com/p/processing/issues/detail?id=1386
+_ fix blue-channel bias on blend() so that blendMode() will work in 2.0
+_ http://code.google.com/p/processing/issues/detail?id=475
+_ blend() bugs with identically-sized images
+_ http://code.google.com/p/processing/issues/detail?id=285
+_ improve blend() accuracy when using ADD
+_ http://code.google.com/p/processing/issues/detail?id=133
+_ includes code for a slow but more accurate mode
+_ implement a more efficient version of blend()
+_ http://code.google.com/p/processing/issues/detail?id=120
+
2.0
_ get() or copy()? for vectors, image, etc.
_ PVector chaining -> Dan looking into this
_ PNode.getChildren() shouldn't make a new array.. toArray() can do that
_ toArray(), toArray(float[]), toVectorArray(), toVectorArray(PVector[])
_ toColorArray(), toColorArray(float[])...
-_ remove blend(), add blendMode()
-_ fix blue-channel bias on blend() so that blendMode() will work in 2.0
-_ http://code.google.com/p/processing/issues/detail?id=475
_ load/save methods.. is it save("blah.svg") or saveSVG("blah.svg")
X also works that way with tables
X decision: useExtension() or something like that
@@ -465,17 +482,12 @@ _ http://code.google.com/p/processing/issues/detail?id=167
_ image resizing is ugly (just use java2d?)
_ also deal with copy()/blend() inaccuracies
_ http://code.google.com/p/processing/issues/detail?id=332
-_ blend() bugs with identically-sized images
-_ http://code.google.com/p/processing/issues/detail?id=285
_ transparency issue with JAVA2D
_ http://code.google.com/p/processing/issues/detail?id=182
_ copy(image with transparency) doesn't keep the transparency at start up
_ http://code.google.com/p/processing/issues/detail?id=601
_ accuracy problems make alpha channel go to FE with image.copy()
_ http://code.google.com/p/processing/issues/detail?id=219
-_ improve blend() accuracy when using ADD
-_ http://code.google.com/p/processing/issues/detail?id=133
-_ includes code for a slow but more accurate mode
_ for a PGraphics2D, should its image cache object be the memoryimagesource?
_ loading lots of images is a problem, describe how to unload
_ is it possible? necessary to call delay(5) or something?
@@ -514,7 +526,6 @@ _ when using get(), reset the bounds for the objects
_ otherwise it's always relative to the original document
_ support for text (shouldn't be too bad, use createFont)
_ implement text spans for svg output
-_ try enabling blending modes
_ add better support for attributes buried in styles (support ai9/10/11)
_ test what happens when transparency is used with gradient fill
_ look into transformation issues... guessing this is probably wrong
@@ -594,15 +605,11 @@ _ will need to split each based on the other
_ sort issues will affect both
_ Stroking a rect() leaves off the upper right pixel
_ http://code.google.com/p/processing/issues/detail?id=67
-_ implement a more efficient version of blend()
-_ http://code.google.com/p/processing/issues/detail?id=120
_ Implement anisotropic filtering when using OPENGL
_ http://code.google.com/p/processing/issues/detail?id=502
_ Signature issue on contributed libraries affects unrelated opengl sketches
_ http://code.google.com/p/processing/issues/detail?id=261
_ remove matrixMode(), add a projection() method
-_ remove screenBlend(), textureBlend() from PGraphics et al
-_ have andres take over all current GL issues in the tracker
_ opengl applet problems with tabs - needs to handle stop() and start()
_ http://code.google.com/p/processing/issues/detail?id=196
_ stop() called between tabs/pages, start() may be called again
@@ -616,6 +623,7 @@ _ opengl isn't drawing rectangles out to raw properly with fonts
_ when not in textMode(SHAPE) should have rects
+
CORE / Mac OS X
_ set the application name to sketch name (not processing.core.PApplet)
diff --git a/core/src/processing/core/PApplet.java b/core/src/processing/core/PApplet.java
index e48c5caee..49ddb6204 100644
--- a/core/src/processing/core/PApplet.java
+++ b/core/src/processing/core/PApplet.java
@@ -2353,6 +2353,7 @@ public class PApplet extends Applet
//////////////////////////////////////////////////////////////
+ // TODO this needs lots of cleaning
public void postEvent(processing.event.Event pe) {
if (pe instanceof MouseEvent) {
if (looping) {
@@ -4703,17 +4704,17 @@ public class PApplet extends Applet
* ( end auto-generated )
* @webref math:calculation
* @param value the incoming value to be converted
* @param istart lower bound of the value's current range
* @param istop upper bound of the value's current range
* @param ostart lower bound of the value's target range
* @param ostop upper bound of the value's target range
* @see PApplet#norm(float, float, float)
* @see PApplet#lerp(float, float, float)
*/
static public final float map(float value,
- float istart, float istop,
- float ostart, float ostop) {
- return ostart + (ostop - ostart) * ((value - istart) / (istop - istart));
+ float start1, float stop1,
+ float start2, float stop2) {
+ return start2 + (stop2 - start2) * ((value - start1) / (stop1 - start1));
}
@@ -10448,7 +10449,7 @@ public class PApplet extends Applet
* Description to come...
*
* ( end auto-generated from textureWrap.xml )
- *
+ *
* @webref image:textures
* @param wrap Either CLAMP (default) or REPEAT
*/
@@ -10617,7 +10618,7 @@ public class PApplet extends Applet
* This is a new reference entry for Processing 2.0. It will be updated shortly.
*
* ( end auto-generated )
- *
+ *
* @webref Rendering
* @param mode the blending mode to use
*/
@@ -10661,7 +10662,7 @@ public class PApplet extends Applet
* This is a new reference entry for Processing 2.0. It will be updated shortly.
*
* ( end auto-generated )
- *
+ *
* @webref rendering:shaders
* @param fragFilename name of fragment shader file
*/
@@ -10684,7 +10685,7 @@ public class PApplet extends Applet
* This is a new reference entry for Processing 2.0. It will be updated shortly.
*
* ( end auto-generated )
- *
+ *
* @webref rendering:shaders
* @param shader name of shader file
*/
@@ -10709,7 +10710,7 @@ public class PApplet extends Applet
* This is a new reference entry for Processing 2.0. It will be updated shortly.
*
* ( end auto-generated )
- *
+ *
* @webref rendering:shaders
*/
public void resetShader() {
@@ -11590,9 +11591,9 @@ public class PApplet extends Applet
/**
- *
+ *
* @param level either 2, 4, or 8
- */
+ */
public void smooth(int level) {
if (recorder != null) recorder.smooth(level);
g.smooth(level);
@@ -12256,8 +12257,8 @@ public class PApplet extends Applet
* ( end auto-generated )
*
* @webref transform
- * @param tx left/right translation
- * @param ty up/down translation
+ * @param x left/right translation
+ * @param y up/down translation
* @see PGraphics#popMatrix()
* @see PGraphics#pushMatrix()
* @see PGraphics#rotate(float)
@@ -12266,18 +12267,18 @@ public class PApplet extends Applet
* @see PGraphics#rotateZ(float)
* @see PGraphics#scale(float, float, float)
*/
- public void translate(float tx, float ty) {
- if (recorder != null) recorder.translate(tx, ty);
- g.translate(tx, ty);
+ public void translate(float x, float y) {
+ if (recorder != null) recorder.translate(x, y);
+ g.translate(x, y);
}
/**
- * @param tz forward/backward translation
+ * @param z forward/backward translation
*/
- public void translate(float tx, float ty, float tz) {
- if (recorder != null) recorder.translate(tx, ty, tz);
- g.translate(tx, ty, tz);
+ public void translate(float x, float y, float z) {
+ if (recorder != null) recorder.translate(x, y, z);
+ g.translate(x, y, z);
}
@@ -12423,13 +12424,13 @@ public class PApplet extends Applet
/**
*
Advanced
* Rotate about a vector in space. Same as the glRotatef() function.
- * @param vx
- * @param vy
- * @param vz
+ * @param x
+ * @param y
+ * @param z
*/
- public void rotate(float angle, float vx, float vy, float vz) {
- if (recorder != null) recorder.rotate(angle, vx, vy, vz);
- g.rotate(angle, vx, vy, vz);
+ public void rotate(float angle, float x, float y, float z) {
+ if (recorder != null) recorder.rotate(angle, x, y, z);
+ g.rotate(angle, x, y, z);
}
@@ -4703,17 +4704,17 @@ public class PApplet extends Applet
* @webref math:calculation
* @param value the incoming value to be converted
- * @param istart lower bound of the value's current range
- * @param istop upper bound of the value's current range
- * @param ostart lower bound of the value's target range
- * @param ostop upper bound of the value's target range
+ * @param start1 lower bound of the value's current range
+ * @param stop1 upper bound of the value's current range
+ * @param start2 lower bound of the value's target range
+ * @param stop2 upper bound of the value's target range
* @see PApplet#norm(float, float, float)
* @see PApplet#lerp(float, float, float)